@@ -67,6 +67,9 @@ namespace CodechalDbgAttr        = MediaDbgAttr;
 #define CODECHAL_DEBUG_ASSERTMESSAGE(_message, ...) \
     MOS_ASSERTMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_DEBUG, _message, ##__VA_ARGS__)
 
+#define CODECHAL_DEBUG_WARNINGMESSAGE(_message, ...) \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_DEBUG, _message, ##__VA_ARGS__)
+
 #define CODECHAL_DEBUG_NORMALMESSAGE(_message, ...) \
     MOS_NORMALMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_DEBUG, _message, ##__VA_ARGS__)
 
@@ -359,6 +362,21 @@ protected:
             CODECHAL_MEDIA_STATE_TYPE mediaState)>
         m_dumpBufferLegacy;
 
+private:
+    MOS_STATUS VDBypassCopyResource(PMOS_RESOURCE src, PMOS_RESOURCE dst);
+    MOS_STATUS AllocateLinearResource(
+        MOS_GFXRES_TYPE eType,
+        uint32_t        dwWidth,
+        uint32_t        dwHeight,
+        MOS_FORMAT      eFormat,
+        PMOS_RESOURCE   pResource,
+        bool            bSystemMem = false,
+        bool            bLockable = false) const;
+    MOS_STATUS FillResourceMemory(
+        MOS_RESOURCE &sResource,
+        uint32_t      uiSize,
+        uint8_t       ucValue);
+
 MEDIA_CLASS_DEFINE_END(CodechalDebugInterface)
 };
 #else
