@@ -46,8 +46,16 @@ enum HuCFunction
 #define ENCODE_ASSERT(_expr)                                                   \
     MOS_ASSERT(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_ENCODE, _expr)
 
+#if (_DEBUG || _RELEASE_INTERNAL)
 #define ENCODE_ASSERTMESSAGE(_message, ...)                                    \
     MOS_ASSERTMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_ENCODE, _message, ##__VA_ARGS__)
+#else
+#define ENCODE_ASSERTMESSAGE(_message, ...)                                    \
+    OcaOnMosCriticalMessage(MOS_FUNCTION, __LINE__);
+#endif
+
+#define ENCODE_WARNINGMESSAGE(_message, ...)                                   \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_ENCODE, _message, ##__VA_ARGS__)
 
 #define ENCODE_NORMALMESSAGE(_message, ...)                                    \
     MOS_NORMALMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_ENCODE, _message, ##__VA_ARGS__)
@@ -67,8 +75,8 @@ enum HuCFunction
 #define ENCODE_CHK_STATUS_NO_STATUS_RETURN(_stmt)                                               \
     MOS_CHK_STATUS_NO_STATUS_RETURN(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_ENCODE, _stmt)
 
-#define ENCODE_CHK_COND_RETURN(_stmt, _message)                                               \
-    MOS_CHK_COND_RETURN(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_ENCODE, _stmt, _message)
+#define ENCODE_CHK_COND_RETURN(_stmt, _message, ...)                                            \
+    MOS_CHK_COND_RETURN(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_ENCODE, _stmt, _message, ##__VA_ARGS__)
 
 #define ENCODE_CHK_STATUS_MESSAGE_RETURN(_stmt, _message, ...)                        \
     MOS_CHK_STATUS_MESSAGE_RETURN(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_ENCODE, _stmt, _message, ##__VA_ARGS__)
