@@ -237,18 +237,9 @@ MOS_STATUS XRenderHal_Platform_Interface_Next::EnablePreemption(
     MEDIA_FEATURE_TABLE* m_skuTable = nullptr;
     MHW_RENDERHAL_CHK_NULL_RETURN(pRenderHal);
     MHW_RENDERHAL_CHK_NULL_RETURN(m_miItf);
+    MHW_RENDERHAL_CHK_NULL_RETURN(m_renderItf);
 
-    m_skuTable = pRenderHal->pOsInterface->pfnGetSkuTable(pRenderHal->pOsInterface);
-    MHW_MI_CHK_NULL(m_skuTable);
-
-    if (MEDIA_IS_SKU(m_skuTable, FtrPerCtxtPreemptionGranularityControl))
-    {
-        auto& par = m_miItf->MHW_GETPAR_F(MI_LOAD_REGISTER_IMM)();
-        par = {};
-        par.dwRegister = 0;
-        par.dwData     = 0;
-        MHW_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_IMM)(pCmdBuffer));
-    }
+    MHW_RENDERHAL_CHK_STATUS_RETURN(m_renderItf->EnablePreemption(pCmdBuffer, m_miItf));
 
     return eStatus;
 }
@@ -926,9 +917,74 @@ bool XRenderHal_Platform_Interface_Next::PerThreadScratchSpaceStart64Byte(RENDER
     return true;
 }
 
+uint32_t XRenderHal_Platform_Interface_Next::CalculatePreferredSlmAllocationSizeFromSlmSize(
+    RENDERHAL_INTERFACE *renderHal, 
+    uint32_t             slmSize, 
+    uint32_t             numberOfThreadsPerThreadGroup)
+{
+    if (!renderHal || !renderHal->pOsInterface || !renderHal->pOsInterface->pfnGetGtSystemInfo)
+    {
+        MHW_RENDERHAL_ASSERTMESSAGE("renderhal or osInterface or pfnGetGtSystemInfo is nullptr");
+        return 0;
+    }
+    if (numberOfThreadsPerThreadGroup == 0)
+    {
+        MHW_RENDERHAL_ASSERTMESSAGE("numberOfThreadsPerThreadGroup is 0");
+        return 0;
+    }
+
+    MEDIA_SYSTEM_INFO *gtInfo = renderHal->pOsInterface->pfnGetGtSystemInfo(renderHal->pOsInterface);
+    if (!gtInfo)
+    {
+        MHW_RENDERHAL_ASSERTMESSAGE("GtSystemInfo is nullptr");
+        return 0;
+    }
+    if (gtInfo->SubSliceCount == 0)
+    {
+        MHW_RENDERHAL_ASSERTMESSAGE("SubSliceCount is 0");
+        return 0;
+    }
+    uint32_t preferredSlmAllicationSize = 0;
+    slmSize                             = slmSize / 1024 + (slmSize % 1024 != 0);
+    uint32_t threadsPerDssCount         = gtInfo->ThreadCount / gtInfo->SubSliceCount;
+    uint32_t workGroupCountPerDss       = (threadsPerDssCount + numberOfThreadsPerThreadGroup - 1) / numberOfThreadsPerThreadGroup;
+    uint32_t slmSizePerSubSlice         = slmSize * workGroupCountPerDss;
+    if (slmSize == 0)
+    {
+        preferredSlmAllicationSize = 0;
+    }
+    else if (slmSizePerSubSlice <= 16)
+    {
+        preferredSlmAllicationSize = 1;
+    }
+    else if (slmSizePerSubSlice <= 32)
+    {
+        preferredSlmAllicationSize = 2;
+    }
+    else if (slmSizePerSubSlice > 256)
+    {
+        if (slmSizePerSubSlice > 384)
+        {
+            MHW_RENDERHAL_ASSERTMESSAGE("slmSizePerSubSlice %d is bigger than max size", slmSizePerSubSlice);
+        }
+        else
+        {
+            preferredSlmAllicationSize = 10;
+        }
+    }
+    else
+    {
+        preferredSlmAllicationSize = slmSizePerSubSlice / 32 + (slmSizePerSubSlice % 32 != 0) + 1;
+    }
+    
+    return preferredSlmAllicationSize;
+}
+
 uint32_t XRenderHal_Platform_Interface_Next::EncodeSLMSize(uint32_t SLMSize)
 {
     uint32_t EncodedValue;
+    SLMSize = SLMSize / 1024 + (SLMSize % 1024 != 0);
+
     if (SLMSize <= 2)
     {
         EncodedValue = SLMSize;
@@ -938,6 +994,10 @@ uint32_t XRenderHal_Platform_Interface_Next::EncodeSLMSize(uint32_t SLMSize)
         EncodedValue = 0;
         do
         {
+            if (SLMSize != 1 && (SLMSize & 0x1) != 0)
+            {
+                ++SLMSize;
+            }
             SLMSize >>= 1;
             EncodedValue++;
         } while (SLMSize);
@@ -1163,11 +1223,27 @@ MOS_STATUS XRenderHal_Platform_Interface_Next::SendComputeWalker(
                                        pRenderHal->pStateHeap->dwOffsetSampler +
                                        pGpGpuWalkerParams->InterfaceDescriptorOffset * pRenderHal->pStateHeap->dwSizeSamplers;
     mhwIdEntryParams.dwBindingTableOffset          = pGpGpuWalkerParams->BindingTableID * pRenderHal->pStateHeap->iBindingTableSize;
-    mhwIdEntryParams.dwSharedLocalMemorySize       = pGpGpuWalkerParams->SLMSize;
-    mhwIdEntryParams.dwNumberofThreadsInGPGPUGroup = pGpGpuWalkerParams->ThreadWidth * pGpGpuWalkerParams->ThreadHeight;
+    mhwIdEntryParams.dwSharedLocalMemorySize       = m_renderHal->pfnEncodeSLMSize(m_renderHal, pGpGpuWalkerParams->SLMSize);
+    if (pGpGpuWalkerParams->isGenerateLocalID && pGpGpuWalkerParams->emitLocal != MHW_EMIT_LOCAL_NONE)
+    {
+        //When COMPUTE_WALKER Emit Local ID is enabled, thread group number need to divide MHW_RENDER_ENGINE_NUMBER_OF_THREAD_UNIT
+        uint32_t engineNumberOfThreadUnit              = (pGpGpuWalkerParams->simdSize == 16) ? 16 : MHW_RENDER_ENGINE_NUMBER_OF_THREAD_UNIT;
+        mhwIdEntryParams.dwNumberofThreadsInGPGPUGroup = MOS_MAX(1, pGpGpuWalkerParams->ThreadWidth * pGpGpuWalkerParams->ThreadHeight / engineNumberOfThreadUnit);
+        if (mhwIdEntryParams.dwNumberofThreadsInGPGPUGroup > 1024 / engineNumberOfThreadUnit)
+        {
+            MHW_RENDERHAL_ASSERTMESSAGE("Number of Threads In GpGpuGroup %d Exceeds the Max Number %d", mhwIdEntryParams.dwNumberofThreadsInGPGPUGroup, 1024 / engineNumberOfThreadUnit);
+            MHW_RENDERHAL_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
+        }
+    }
+    else
+    {
+        mhwIdEntryParams.dwNumberofThreadsInGPGPUGroup = pGpGpuWalkerParams->ThreadWidth * pGpGpuWalkerParams->ThreadHeight;
+    }
+    mhwIdEntryParams.preferredSlmAllocationSize = CalculatePreferredSlmAllocationSizeFromSlmSize(m_renderHal, pGpGpuWalkerParams->SLMSize, mhwIdEntryParams.dwNumberofThreadsInGPGPUGroup);
     //This only a WA to disable EU fusion for multi-layer blending cases or single layer do colorfill and rotation together.
     //Need remove it after kernel or compiler fix it.
     mhwIdEntryParams.bBarrierEnable              = pRenderHal->eufusionBypass ? 1 : 0;
+    mhwIdEntryParams.bBarrierEnable             |= pGpGpuWalkerParams->hasBarrier;
     pGpGpuWalkerParams->IndirectDataStartAddress = pGpGpuWalkerParams->IndirectDataStartAddress + pRenderHal->pStateHeap->pCurMediaState->dwOffset;
 
     MHW_RENDERHAL_CHK_NULL_RETURN(m_renderItf);
@@ -1432,6 +1508,7 @@ MHW_SETPAR_DECL_SRC(STATE_BASE_ADDRESS, XRenderHal_Platform_Interface_Next)
     params.mocs4SurfaceState = pStateBaseParams->mocs4SurfaceState;
     params.mocs4IndirectObjectBuffer = pStateBaseParams->mocs4IndirectObjectBuffer;
     params.mocs4StatelessDataport = pStateBaseParams->mocs4StatelessDataport;
+    params.addressDis                 = m_renderHal->isBindlessHeapInUse;
 
     return MOS_STATUS_SUCCESS;
 }
@@ -1467,29 +1544,32 @@ MHW_SETPAR_DECL_SRC(COMPUTE_WALKER, XRenderHal_Platform_Interface_Next)
 {
     MHW_RENDERHAL_CHK_NULL_RETURN(m_gpgpuWalkerParams);
     MHW_RENDERHAL_CHK_NULL_RETURN(m_interfaceDescriptorParams);
+    MHW_RENDERHAL_CHK_NULL_RETURN(m_renderHal);
 
-    params.IndirectDataLength = m_gpgpuWalkerParams->IndirectDataLength;
+    params.simdSize                 = m_gpgpuWalkerParams->simdSize;
+    params.IndirectDataLength       = m_gpgpuWalkerParams->IndirectDataLength;
     params.IndirectDataStartAddress = m_gpgpuWalkerParams->IndirectDataStartAddress;
-    params.ThreadWidth = m_gpgpuWalkerParams->ThreadWidth;
-    params.ThreadHeight = m_gpgpuWalkerParams->ThreadHeight;
-    params.ThreadDepth = m_gpgpuWalkerParams->ThreadDepth;
+    params.ThreadWidth              = m_gpgpuWalkerParams->ThreadWidth;
+    params.ThreadHeight             = m_gpgpuWalkerParams->ThreadHeight;
+    params.ThreadDepth              = m_gpgpuWalkerParams->ThreadDepth;
 
-    params.GroupWidth = m_gpgpuWalkerParams->GroupWidth;
-    params.GroupHeight = m_gpgpuWalkerParams->GroupHeight;
-    params.GroupDepth = m_gpgpuWalkerParams->GroupDepth;
+    params.GroupWidth     = m_gpgpuWalkerParams->GroupWidth;
+    params.GroupHeight    = m_gpgpuWalkerParams->GroupHeight;
+    params.GroupDepth     = m_gpgpuWalkerParams->GroupDepth;
     params.GroupStartingX = m_gpgpuWalkerParams->GroupStartingX;
     params.GroupStartingY = m_gpgpuWalkerParams->GroupStartingY;
     params.GroupStartingZ = m_gpgpuWalkerParams->GroupStartingZ;
 
-    params.dwKernelOffset = m_interfaceDescriptorParams->dwKernelOffset;
-    params.dwSamplerCount = m_interfaceDescriptorParams->dwSamplerCount;
-    params.dwSamplerOffset = m_interfaceDescriptorParams->dwSamplerOffset;
-    params.dwBindingTableOffset = m_interfaceDescriptorParams->dwBindingTableOffset;;
-    params.bBarrierEnable = m_interfaceDescriptorParams->bBarrierEnable;
+    params.dwKernelOffset                = m_interfaceDescriptorParams->dwKernelOffset;
+    params.dwSamplerCount                = m_interfaceDescriptorParams->dwSamplerCount;
+    params.dwSamplerOffset               = m_interfaceDescriptorParams->dwSamplerOffset;
+    params.dwBindingTableOffset          = m_interfaceDescriptorParams->dwBindingTableOffset;
+    params.bBarrierEnable                = m_interfaceDescriptorParams->bBarrierEnable;
     params.dwNumberofThreadsInGPGPUGroup = m_interfaceDescriptorParams->dwNumberofThreadsInGPGPUGroup;
-    params.dwSharedLocalMemorySize = m_interfaceDescriptorParams->dwSharedLocalMemorySize;
-    params.IndirectDataStartAddress = m_gpgpuWalkerParams->IndirectDataStartAddress;
-    params.forcePreferredSLMZero = m_gpgpuWalkerParams->ForcePreferredSLMZero;
+    params.dwSharedLocalMemorySize       = m_interfaceDescriptorParams->dwSharedLocalMemorySize;
+    params.preferredSlmAllocationSize    = m_interfaceDescriptorParams->preferredSlmAllocationSize;
+    params.IndirectDataStartAddress      = m_gpgpuWalkerParams->IndirectDataStartAddress;
+    params.forcePreferredSLMZero         = m_gpgpuWalkerParams->ForcePreferredSLMZero;
 
     if (m_gpgpuWalkerParams->ThreadDepth == 0)
     {
@@ -1499,6 +1579,36 @@ MHW_SETPAR_DECL_SRC(COMPUTE_WALKER, XRenderHal_Platform_Interface_Next)
     {
         params.GroupDepth = 1;
     }
+    if (m_gpgpuWalkerParams->simdSize == 0)
+    {
+        params.simdSize = 32;
+    }
+
+    params.isEmitInlineParameter = m_gpgpuWalkerParams->isEmitInlineParameter;
+    if (m_gpgpuWalkerParams->inlineDataLength > 0 && m_gpgpuWalkerParams->inlineData)
+    {
+        params.inlineDataLength = m_gpgpuWalkerParams->inlineDataLength;
+        params.inlineData       = m_gpgpuWalkerParams->inlineData;
+    }
+
+    params.isGenerateLocalId = m_gpgpuWalkerParams->isGenerateLocalID;
+    params.emitLocal         = mhw::render::MHW_EMIT_LOCAL_MODE(m_gpgpuWalkerParams->emitLocal);
+
+    params.heapsResource.curbeResourceList      = m_gpgpuWalkerParams->curbeResourceList;
+    params.heapsResource.curbeResourceListSize  = m_gpgpuWalkerParams->curbeResourceListSize;
+    params.heapsResource.inlineResourceList     = m_gpgpuWalkerParams->inlineResourceList;
+    params.heapsResource.inlineResourceListSize = m_gpgpuWalkerParams->inlineResourceListSize;
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MHW_SETPAR_DECL_SRC(_3DSTATE_BINDING_TABLE_POOL_ALLOC, XRenderHal_Platform_Interface_Next)
+{
+    MHW_STATE_BASE_ADDR_PARAMS *pStateBaseParams = nullptr;
+    MHW_RENDERHAL_CHK_NULL_RETURN(m_renderHal);
+    pStateBaseParams = &m_renderHal->StateBaseAddressParams;
+    MHW_RENDERHAL_CHK_NULL_RETURN(pStateBaseParams);
+    params.mocs4SurfaceState = pStateBaseParams->mocs4SurfaceState;
 
     return MOS_STATUS_SUCCESS;
 }
\ No newline at end of file
