@@ -134,6 +134,8 @@ MOS_STATUS VpRenderCmdPacket::LoadKernel()
         return MOS_STATUS_UNKNOWN;
     }
     // Allocate Media ID, link to kernel
+    // iCurbeOffset and iCurbeLength is useless in bindless mode
+    // pRenderHal->pfnSetupInterfaceDesc is not used in bindless mode, it's set in send compute walker
     m_renderData.mediaID = m_renderHal->pfnAllocateMediaID(
         m_renderHal,
         iKrnAllocation,
@@ -271,12 +273,23 @@ MOS_STATUS VpRenderCmdPacket::Prepare()
 
             VP_RENDER_CHK_STATUS_RETURN(SetupSurfaceState());  // once Surface setup done, surface index should be created here
 
-            VP_RENDER_CHK_STATUS_RETURN(SetupCurbeState());  // Set Curbe with updated surface index
+            if (m_renderHal->isBindlessHeapInUse == false)
+            {
+                VP_RENDER_CHK_STATUS_RETURN(SetupCurbeState());  // Set Curbe with updated surface index
+            }
 
             VP_RENDER_CHK_STATUS_RETURN(LoadKernel());
 
             VP_RENDER_CHK_STATUS_RETURN(SetupSamplerStates());
 
+            if (m_renderHal->isBindlessHeapInUse)
+            {
+                // In bindless mode, Curbe need to set after surface state setup and sampler state setup
+                // Since bindless surface and bindless sampler only can be set into curbe after they are setup
+                // In bindful mode, they don't need to be set in curbe
+                VP_RENDER_CHK_STATUS_RETURN(SetupCurbeStateInBindlessMode());
+            }
+
             VP_RENDER_CHK_STATUS_RETURN(SetupWalkerParams());
 
             VP_RENDER_CHK_STATUS_RETURN(m_renderHal->pfnSetVfeStateParams(
@@ -349,12 +362,23 @@ MOS_STATUS VpRenderCmdPacket::Prepare()
 
             VP_RENDER_CHK_STATUS_RETURN(SetupSurfaceState());  // once Surface setup done, surface index should be created here
 
-            VP_RENDER_CHK_STATUS_RETURN(SetupCurbeState());  // Set Curbe with updated surface index
+            if (m_renderHal->isBindlessHeapInUse == false)
+            {
+                VP_RENDER_CHK_STATUS_RETURN(SetupCurbeState());  // Set Curbe with updated surface index
+            }
 
             VP_RENDER_CHK_STATUS_RETURN(LoadKernel());
 
             VP_RENDER_CHK_STATUS_RETURN(SetupSamplerStates());
 
+            if (m_renderHal->isBindlessHeapInUse)
+            {
+                // In bindless mode, Curbe need to set after surface state setup and sampler state setup
+                // Since bindless surface and bindless sampler only can be set into curbe after they are setup
+                // In bindful mode, they don't need to be set in curbe
+                VP_RENDER_CHK_STATUS_RETURN(SetupCurbeStateInBindlessMode());
+            }
+
             VP_RENDER_CHK_STATUS_RETURN(SetupWalkerParams());
 
             m_kernelRenderData.emplace(it->first, m_renderData);
@@ -402,6 +426,7 @@ MOS_STATUS VpRenderCmdPacket::SetupSamplerStates()
         }
         else
         {
+            VP_RENDER_NORMALMESSAGE("Sampler State is empty for samplerIndex %d", samplerIndex);
             MHW_SAMPLER_STATE_PARAM param = {};
             samplerStates.push_back(param);
         }
@@ -450,7 +475,6 @@ MOS_STATUS VpRenderCmdPacket::Submit(MOS_COMMAND_BUFFER *commandBuffer, uint8_t
         return MOS_STATUS_INVALID_PARAMETER;
     }
 
-
     if (!m_surfSetting.dumpLaceSurface &&
         !m_surfSetting.dumpPostSurface)
     {
@@ -756,7 +780,7 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
                 bWrite = false;
             }
 
-            std::set<uint32_t> stateOffsets;
+            std::vector<RENDERHAL_STATE_LOCATION> stateLocations;
             if (kernelSurfaceParam->surfaceOverwriteParams.bindedKernel && !kernelSurfaceParam->surfaceOverwriteParams.bufferResource)
             {
                 auto bindingMap = m_kernel->GetSurfaceBindingIndex(type);
@@ -770,7 +794,7 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
                     &renderSurfaceParams,
                     bindingMap,
                     bWrite,
-                    stateOffsets,
+                    stateLocations,
                     kernelSurfaceParam->iCapcityOfSurfaceEntry,
                     kernelSurfaceParam->surfaceEntries,
                     kernelSurfaceParam->sizeOfSurfaceEntries));
@@ -796,7 +820,7 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
                         &renderSurfaceParams,
                         bindingMap,
                         bWrite,
-                        stateOffsets));
+                        stateLocations));
                     for (uint32_t const &bti : bindingMap)
                     {
                         VP_RENDER_NORMALMESSAGE("Using Binded Index Buffer. KernelID %d, SurfType %d, bti %d", m_kernel->GetKernelId(), type, bti);
@@ -814,7 +838,7 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
                         &renderHalSurface,
                         &renderSurfaceParams,
                         bWrite,
-                        stateOffsets);
+                        stateLocations);
                     VP_RENDER_CHK_STATUS_RETURN(m_kernel->UpdateCurbeBindingIndex(type, index));
                     VP_RENDER_NORMALMESSAGE("Using UnBinded Index Buffer. KernelID %d, SurfType %d, bti %d", m_kernel->GetKernelId(), type, index);
                 }
@@ -825,15 +849,15 @@ MOS_STATUS VpRenderCmdPacket::SetupSurfaceState()
                         &renderHalSurface,
                         &renderSurfaceParams,
                         bWrite,
-                        stateOffsets);
+                        stateLocations);
                     VP_RENDER_CHK_STATUS_RETURN(m_kernel->UpdateCurbeBindingIndex(type, index));
                     VP_RENDER_NORMALMESSAGE("Using UnBinded Index Surface. KernelID %d, SurfType %d, bti %d. If 1D buffer overwrite to 2D for use, it will go SetSurfaceForHwAccess()", m_kernel->GetKernelId(), type, index);
                 }
             }
 
-            if (stateOffsets.size() > 0)
+            if (stateLocations.size() > 0)
             {
-                m_kernel->UpdateBindlessSurfaceResource(type, stateOffsets);
+                m_kernel->UpdateBindlessSurfaceResource(type, stateLocations);
             }
         }
         VP_RENDER_CHK_STATUS_RETURN(m_kernel->UpdateCompParams());
@@ -946,6 +970,48 @@ bool VpRenderCmdPacket::IsRenderUncompressedWriteNeeded(PVP_SURFACE VpSurface)
     return false;
 }
 
+MOS_STATUS VpRenderCmdPacket::SetupCurbeStateInBindlessMode()
+{
+    VP_FUNC_CALL();
+    MT_LOG1(MT_VP_HAL_RENDER_SETUP_CURBE_STATE, MT_NORMAL, MT_FUNC_START, 1);
+    VP_RENDER_CHK_NULL_RETURN(m_kernel);
+    VP_PUBLIC_CHK_NULL_RETURN(m_renderHal->pStateHeap);
+    // set the Curbe Data length
+    void    *curbeData          = nullptr;
+    uint32_t curbeLength        = 0;
+    uint32_t curbeLengthAligned = 0;
+
+    VP_RENDER_CHK_STATUS_RETURN(m_kernel->GetCurbeState(curbeData, curbeLength, curbeLengthAligned, m_renderData.KernelParam, m_renderHal->dwCurbeBlockAlign));
+
+    m_renderData.iCurbeOffset = m_renderHal->pfnLoadCurbeData(
+        m_renderHal,
+        m_renderData.mediaState,
+        curbeData,
+        curbeLength);
+
+    if (m_renderData.iCurbeOffset < 0 ||
+        (m_renderData.iCurbeOffset & 0x1F) != 0 ||
+        (m_renderData.iCurbeOffset + static_cast<int32_t>(curbeLengthAligned)) > m_renderData.mediaState->iCurbeOffset)
+    {
+        RENDER_PACKET_ASSERTMESSAGE("Curbe Set Fail, return error");
+        return MOS_STATUS_UNKNOWN;
+    }
+
+    VP_PUBLIC_CHK_STATUS_RETURN(m_kernel->UpdateCurbeStateHeapInfo(
+        &m_renderHal->pStateHeap->GshOsResource, 
+        m_renderHal->pStateHeap->pGshBuffer, 
+        m_renderHal->pStateHeap->pCurMediaState->dwOffset + m_renderHal->pStateHeap->dwOffsetCurbe + m_renderData.iCurbeOffset));
+
+    m_renderData.iCurbeLength = curbeLengthAligned;
+
+    m_totalCurbeSize += m_renderData.iCurbeLength;
+
+    m_kernel->FreeCurbe(curbeData);
+    MT_LOG2(MT_VP_HAL_RENDER_SETUP_CURBE_STATE, MT_NORMAL, MT_FUNC_END, 1, MT_MOS_STATUS, MOS_STATUS_SUCCESS);
+
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS VpRenderCmdPacket::SetupCurbeState()
 {
     VP_FUNC_CALL();
@@ -975,6 +1041,12 @@ MOS_STATUS VpRenderCmdPacket::SetupCurbeState()
  
     m_totalCurbeSize += m_renderData.iCurbeLength;
 
+    VP_RENDER_CHK_NULL_RETURN(m_renderHal->pStateHeap);
+    VP_PUBLIC_CHK_STATUS_RETURN(m_kernel->UpdateCurbeStateHeapInfo(
+        &m_renderHal->pStateHeap->GshOsResource,
+        m_renderHal->pStateHeap->pGshBuffer,
+        m_renderHal->pStateHeap->pCurMediaState->dwOffset + m_renderHal->pStateHeap->dwOffsetCurbe + m_renderData.iCurbeOffset));
+
     m_kernel->FreeCurbe(curbeData);
     MT_LOG2(MT_VP_HAL_RENDER_SETUP_CURBE_STATE, MT_NORMAL, MT_FUNC_END, 1, MT_MOS_STATUS, MOS_STATUS_SUCCESS);
 
@@ -1953,9 +2025,16 @@ MOS_STATUS VpRenderCmdPacket::SendMediaStates(
     // Send State Base Address command
     MHW_RENDERHAL_CHK_STATUS(pRenderHal->pfnSendStateBaseAddress(pRenderHal, pCmdBuffer));
 
-    if (pRenderHal->bComputeContextInUse && !pRenderHal->isBindlessHeapInUse)
+    if (pRenderHal->bComputeContextInUse)
     {
-        pRenderHal->pRenderHalPltInterface->SendTo3DStateBindingTablePoolAlloc(pRenderHal, pCmdBuffer);
+        if (!pRenderHal->isBindlessHeapInUse)
+        {
+            pRenderHal->pRenderHalPltInterface->SendTo3DStateBindingTablePoolAlloc(pRenderHal, pCmdBuffer);
+        }
+        else
+        {
+            pRenderHal->pRenderHalPltInterface->SendStateComputeMode(pRenderHal, pCmdBuffer);
+        }
     }
 
     // Send Surface States
